@@ -100,6 +100,7 @@ StatisticType = Literal["Average", "Maximum", "Minimum", "SampleCount", "Sum"]
 StatusCodeType = Literal["Complete", "InternalError", "PartialData"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -132,6 +133,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
